@@ -1,7 +1,15 @@
-##' ReconstructedLandmarkSet class
-##' @return An \code{ReconstructedLandmarkSet} object, which inherits
-##'   from ReconstructedFeatureSet
+##' Class containing functions and data to map \link{LandmarkSet}s to
+##' \link{ReconstructedOutline}s
+##'
+##' @description A ReconstructedLandmarkSet contains information about
+##'   features located on \code{\link{ReconstructedOutline}}s. Each
+##'   ReconstructedLandmarkSet contains a list of matrices, each of
+##'   which has columns labelled \code{phi} (latitude) and
+##'   \code{lambda} (longitude) describing the spherical coordinates
+##'   of points on the ReconstructedOutline.
+##' 
 ##' @author David Sterratt
+##' @importFrom geometry delaunayn
 ##' @export
 ReconstructedLandmarkSet <- R6Class("ReconstructedLandmarkSet",
   inherit = ReconstructedFeatureSet
@@ -16,6 +24,8 @@ projection.ReconstructedLandmarkSet <-
            projection=azimuthal.equalarea,
            proj.centre=cbind(phi=0, lambda=0),
            lambdalim=c(-180, 180),
+           markup=NULL, # Not used in this function; hides from ...
+           max.proj.dim=NULL, # Not used in this function; hides from ...
            ...)
 {
   for (id in ids) {
