@@ -36,6 +36,44 @@ read.image <- function(dataset, report=message) {
   return(im)
 }
 
+## Copied from demo("colors")
+## @title Comparing Colors
+## @param col
+## @param nrow
+## @param ncol
+## @param txt.col
+## @return the grid layout, invisibly
+## @author Marius Hofert, originally
+plotCol <- function(col, nrow=1, ncol=ceiling(length(col) / nrow),
+                    txt.col="black") {
+    stopifnot(nrow >= 1, ncol >= 1)
+    if(length(col) > nrow*ncol)
+        warning("some colors will not be shown")
+    grid::grid.newpage()
+    gl <- grid::grid.layout(nrow, ncol)
+    grid::pushViewport(grid::viewport(layout=gl))
+    ic <- 1
+    for(i in 1:nrow) {
+        for(j in 1:ncol) {
+            grid::pushViewport(grid::viewport(layout.pos.row=i, layout.pos.col=j))
+            grid::grid.rect(gp= grid::gpar(fill=col[ic]))
+            grid::grid.text(col[ic], gp=grid::gpar(col=txt.col))
+            grid::upViewport()
+            ic <- ic+1
+        }
+    }
+    grid::upViewport()
+    invisible(gl)
+}
+
+check.colour <- function(col) {
+  if (!(col %in% grDevices::colours())) {
+    plotCol(grep("([0-9]|medium|light|dark)",  grDevices::colors(), invert=TRUE, value=TRUE), nrow=20)
+    return(FALSE)
+  }
+  return(TRUE)
+}
+
 ##' Read data points from a file \code{dataponts.csv} in the directory
 ##' \code{dataset}. The CSV should contain two columns for every
 ##' dataset. Each pair of columns must contain a unique name in the
@@ -86,6 +124,9 @@ read.datapoints <- function(dataset) {
       Ds <- c(Ds, D)
 
       col <- names[2]
+      if (!(check.colour(col))) {
+        stop("Invalid colour \"", col, "\" in datapoints.csv - see window for valid colour names")
+      }
       names(col) <- names[1]
       cols <- c(cols, col)
     }
@@ -129,6 +170,7 @@ read.datacounts <- function(dataset) {
       ## Force conversion to matrix, necessary when the data has only
       ## one row
       d <- matrix(d, ncol=3)
+      colnames(d) <- c("X", "Y", "C")
       
       ## Any strings (e.g. empty ones) that don't convert will be
       ## converted to NA. Get rid of these.
@@ -142,6 +184,9 @@ read.datacounts <- function(dataset) {
       Gs <- c(Gs, G)
 
       col <- list(names[2])
+      if (!(check.colour(col))) {
+        stop("Invalid colour \"", col, "\" in datacounts.csv - see window for valid colour names")
+      }
       names(col) <- names[1]
       cols <- c(cols, col)
     }
